@@ -9,13 +9,14 @@ import { TRANSFER_BUFFER } from './parser';
 /** A single node within a syntax {@link Tree}. */
 export class Node {
   /** @internal */
-  private [0] = 0; // Internal handle for WASM
+  // @ts-expect-error: never read
+  private [0] = 0; // Internal handle for Wasm
 
   /** @internal */
-  private _children?: (Node | null)[];
+  private _children?: Node[];
 
   /** @internal */
-  private _namedChildren?: (Node | null)[];
+  private _namedChildren?: Node[];
 
   /** @internal */
   constructor(
@@ -258,7 +259,7 @@ export class Node {
    *
    * See also {@link Node#children}.
    */
-  childrenForFieldName(fieldName: string): (Node | null)[] {
+  childrenForFieldName(fieldName: string): Node[] {
     const fieldId = this.tree.language.fields.indexOf(fieldName);
     if (fieldId !== -1 && fieldId !== 0) return this.childrenForFieldId(fieldId);
     return [];
@@ -269,17 +270,17 @@ export class Node {
     *
     * See also {@link Node#childrenForFieldName}.
     */
-  childrenForFieldId(fieldId: number): (Node | null)[] {
+  childrenForFieldId(fieldId: number): Node[] {
     marshalNode(this);
     C._ts_node_children_by_field_id_wasm(this.tree[0], fieldId);
     const count = C.getValue(TRANSFER_BUFFER, 'i32');
     const buffer = C.getValue(TRANSFER_BUFFER + SIZE_OF_INT, 'i32');
-    const result = new Array<Node | null>(count);
+    const result = new Array<Node>(count);
 
     if (count > 0) {
       let address = buffer;
       for (let i = 0; i < count; i++) {
-        result[i] = unmarshalNode(this.tree, address);
+        result[i] = unmarshalNode(this.tree, address)!;
         address += SIZE_OF_NODE;
       }
       C._free(buffer);
@@ -356,7 +357,7 @@ export class Node {
    * If you're walking the tree recursively, you may want to use the
    * {@link TreeCursor} APIs directly instead.
    */
-  get children(): (Node | null)[] {
+  get children(): Node[] {
     if (!this._children) {
       marshalNode(this);
       C._ts_node_children_wasm(this.tree[0]);
@@ -366,7 +367,7 @@ export class Node {
       if (count > 0) {
         let address = buffer;
         for (let i = 0; i < count; i++) {
-          this._children[i] = unmarshalNode(this.tree, address);
+          this._children[i] = unmarshalNode(this.tree, address)!;
           address += SIZE_OF_NODE;
         }
         C._free(buffer);
@@ -380,7 +381,7 @@ export class Node {
    *
    * See also {@link Node#children}.
    */
-  get namedChildren(): (Node | null)[] {
+  get namedChildren(): Node[] {
     if (!this._namedChildren) {
       marshalNode(this);
       C._ts_node_named_children_wasm(this.tree[0]);
@@ -390,7 +391,7 @@ export class Node {
       if (count > 0) {
         let address = buffer;
         for (let i = 0; i < count; i++) {
-          this._namedChildren[i] = unmarshalNode(this.tree, address);
+          this._namedChildren[i] = unmarshalNode(this.tree, address)!;
           address += SIZE_OF_NODE;
         }
         C._free(buffer);
@@ -410,7 +411,7 @@ export class Node {
     types: string | string[],
     startPosition: Point = ZERO_POINT,
     endPosition: Point = ZERO_POINT
-  ): (Node | null)[] {
+  ): Node[] {
     if (!Array.isArray(types)) types = [types];
 
     // Convert the type strings to numeric type symbols
@@ -427,7 +428,7 @@ export class Node {
       }
     }
 
-    // Copy the array of symbols to the WASM heap
+    // Copy the array of symbols to the Wasm heap
     const symbolsAddress = C._malloc(SIZE_OF_INT * symbols.length);
     for (let i = 0, n = symbols.length; i < n; i++) {
       C.setValue(symbolsAddress + i * SIZE_OF_INT, symbols[i], 'i32');
@@ -448,11 +449,11 @@ export class Node {
     // Instantiate the nodes based on the data returned
     const descendantCount = C.getValue(TRANSFER_BUFFER, 'i32');
     const descendantAddress = C.getValue(TRANSFER_BUFFER + SIZE_OF_INT, 'i32');
-    const result = new Array<Node | null>(descendantCount);
+    const result = new Array<Node>(descendantCount);
     if (descendantCount > 0) {
       let address = descendantAddress;
       for (let i = 0; i < descendantCount; i++) {
-        result[i] = unmarshalNode(this.tree, address);
+        result[i] = unmarshalNode(this.tree, address)!;
         address += SIZE_OF_NODE;
       }
     }
@@ -522,7 +523,7 @@ export class Node {
    */
   childWithDescendant(descendant: Node): Node | null {
     marshalNode(this);
-    marshalNode(descendant);
+    marshalNode(descendant, 1);
     C._ts_node_child_with_descendant_wasm(this.tree[0]);
     return unmarshalNode(this.tree);
   }
@@ -635,7 +636,7 @@ export class Node {
   }
 
   /** Get the S-expression representation of this node. */
-  toString() {
+  toString(): string {
     marshalNode(this);
     const address = C._ts_node_to_string_wasm(this.tree[0]);
     const result = C.AsciiToString(address);
