@@ -64,7 +64,7 @@ describe('Query', () => {
   });
 
   describe('.matches', () => {
-    it('returns all of the matches for the given query', () => {
+    it('returns all of the matches for the given query', { timeout: 10000 }, () => {
       tree = parser.parse('function one() { two(); function three() {} }')!;
       query = new Query(JavaScript, `
         (function_declaration name: (identifier) @fn-def)
@@ -461,17 +461,6 @@ describe('Query', () => {
     });
   });
 
-  describe('Set a timeout', () => {
-    it('returns less than the expected matches', () => {
-      tree = parser.parse('function foo() while (true) { } }\n'.repeat(1000))!;
-      query = new Query(JavaScript, '(function_declaration name: (identifier) @function)');
-      const matches = query.matches(tree.rootNode, { timeoutMicros: 1000 });
-      expect(matches.length).toBeLessThan(1000);
-      const matches2 = query.matches(tree.rootNode, { timeoutMicros: 0 });
-      expect(matches2).toHaveLength(1000);
-    });
-  });
-
   describe('Start and end indices for patterns', () => {
     it('Returns the start and end indices for a pattern', () => {
       const patterns1 = `
@@ -538,7 +527,7 @@ describe('Query', () => {
     });
   });
 
-  describe('Executes with a timeout', () => {
+  describe('Executes with a timeout', { timeout: 10000 }, () => {
     it('Returns less than the expected matches', () => {
       tree = parser.parse('function foo() while (true) { } }\n'.repeat(1000))!;
       query = new Query(JavaScript, '(function_declaration) @function');
